import { Controller, useForm } from "react-hook-form";
import {
	Box,
	Button,
	Typography,
	Modal,
	IconButton,
	InputAdornment,
} from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { Visibility, VisibilityOff } from "@mui/icons-material";
import { useDispatch } from "react-redux";
import { addBooking, bookingList } from "../../redux/slices/bookSlice.ts";
import React, { useState } from "react";
import {
	CustomIconButton,
	CustomTextField,
} from "../AddEditUserModel/styled.css.tsx";

export default function AddBookingModal({
	open,
	handleClose,
}: {
	open: boolean;
	handleClose: () => void;
}) {
	const dispatch = useDispatch();
	const {
		control,
		register,
		handleSubmit,
		formState: { errors },
		reset,
		watch,
	} = useForm();

	const [showPassword, setShowPassword] = useState(false);

	const togglePasswordVisibility = () => setShowPassword((prev) => !prev);

	const onSubmit = async (data: any) => {
		const bookingData = {
			stationId: data.stationId,
			date: data.date,
			startTime: data.startTime,
			endTime: data.endTime,
		};

		try {
			await dispatch(addBooking(bookingData));
			dispatch(bookingList());
			handleClose(); // Close modal after successful addition
			reset(); // Reset form fields
		} catch (error) {
			console.error("Error adding booking:", error);
		}
	};

	return (
		<Modal
			open={open}
			onClose={(e, reason) => {
				if (reason === "backdropClick") {
					return;
				}
				handleClose();
			}}
			aria-labelledby="add-booking-modal"
		>
			<Box
				sx={{
					position: "absolute",
					top: "50%",
					left: "50%",
					transform: "translate(-50%, -50%)",
					width: 400,
					bgcolor: "background.paper",
					boxShadow: 24,
					p: 3,
					borderRadius: 2,
				}}
			>
				{/* Header */}
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						alignItems: "center",
					}}
				>
					<Typography variant="h6" fontWeight={600}>
						Add Booking
					</Typography>
					<CustomIconButton onClick={handleClose}>
						<CloseIcon />
					</CustomIconButton>
				</Box>
				<Box sx={{ borderBottom: "1px solid #ddd", my: 2 }} />

				<form onSubmit={handleSubmit(onSubmit)}>
					{/* Station ID Input */}
					<Box sx={{ display: "flex", gap: 2, mb: 2 }}>
						<Box sx={{ flex: 1 }}>
							<Typography variant="body2" fontWeight={500}>
								Station ID
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Enter Station Id"
								size="small"
								error={!!errors.stationId}
								helperText={
									errors.stationId
										? errors.stationId.message
										: ""
								}
								{...register("stationId", {
									required: "Station ID is required",
								})}
							/>
						</Box>
					</Box>

					{/* Date Input */}
					<Box sx={{ display: "flex", gap: 2, mb: 2 }}>
						<Box sx={{ flex: 1 }}>
							<Typography variant="body2" fontWeight={500}>
								Date
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Select Booking Date"
								size="small"
								type="date"
								error={!!errors.date}
								helperText={
									errors.date ? errors.date.message : ""
								}
								{...register("date", {
									required: "Date is required",
								})}
							/>
						</Box>
					</Box>

					{/* Start Time Input */}
					<Box sx={{ display: "flex", gap: 2, mb: 2 }}>
						<Box sx={{ flex: 1 }}>
							<Typography variant="body2" fontWeight={500}>
								Start Time
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Enter Start Time"
								size="small"
								type="time"
								error={!!errors.startTime}
								helperText={
									errors.startTime
										? errors.startTime.message
										: ""
								}
								{...register("startTime", {
									required: "Start Time is required",
								})}
							/>
						</Box>
					</Box>

					{/* End Time Input */}
					<Box sx={{ display: "flex", gap: 2, mb: 2 }}>
						<Box sx={{ flex: 1 }}>
							<Typography variant="body2" fontWeight={500}>
								End Time
							</Typography>
							<CustomTextField
								fullWidth
								placeholder="Enter End Time"
								size="small"
								type="time"
								error={!!errors.endTime}
								helperText={
									errors.endTime ? errors.endTime.message : ""
								}
								{...register("endTime", {
									required: "End Time is required",
									validate: (value) => {
										const startTime = watch("startTime");
										if (value <= startTime) {
											return "End time must be after start time.";
										}
										return true;
									},
								})}
							/>
						</Box>
					</Box>

					{/* Submit Button */}
					<Box
						sx={{
							display: "flex",
							justifyContent: "flex-end",
							mt: 3,
						}}
					>
						<Button
							type="submit"
							sx={{
								backgroundColor: "#52ACDF",
								color: "white",
								borderRadius: "8px",
								width: "117px",
								"&:hover": { backgroundColor: "#439BC1" },
							}}
						>
							Add Booking
						</Button>
					</Box>
				</form>
			</Box>
		</Modal>
	);
}
