import React, { useEffect, useState } from "react";
import {
	Dialog,
	DialogActions,
	DialogContent,
	DialogTitle,
	Button,
	Typography,
	IconButton,
	Box,
	Snackbar,
	Stack,
	Tabs,
	Tab,
	Card,
} from "@mui/material";

import { CustomTextField } from "../../components/AddEditUserModel/styled.css.tsx";
import AddCircleIcon from "@mui/icons-material/AddCircle";
import DeleteIcon from "@mui/icons-material/Delete";
import CalendarTodayRoundedIcon from "@mui/icons-material/CalendarTodayRounded";
import { LocalizationProvider, DatePicker } from "@mui/x-date-pickers";
import { AdapterDayjs } from "@mui/x-date-pickers/AdapterDayjs";
import dayjs from "dayjs";
import { useDispatch, useSelector } from "react-redux";
import {
	fetchAvailableSlots,
	createSlot,
	deleteSlot,
} from "../../redux/slices/slotSlice.ts";


const days = [
	"Monday",
	"Tuesday",
	"Wednesday",
	"Thursday",
	"Friday",
	"Saturday",
];

interface AddSlotModalProps {
	open: boolean;
	onClose: () => void;
}

export default function AddSlotModal({ open, onClose }: AddSlotModalProps) {
	const [selectedDay, setSelectedDay] = useState("Monday");
	const [openingTime, setOpeningTime] = useState("");
	const [closingTime, setClosingTime] = useState("");
	const [breakTime, setBreakTime] = useState<any>([]);
	const [error, setError] = useState<string>("");
	const [successMessage, setSuccessMessage] = useState<string | null>(null);
	const [selectedDate, setSelectedDate] = useState<dayjs.Dayjs | null>(
		dayjs()
	);
	const dispatch = useDispatch();

	// Fetch slots from the Redux state
	const {
		slots,
		loading,
		error: apiError,
	} = useSelector((state: any) => state.slotReducer.slots);

	// useEffect(() => {
	// 	if (selectedDay) {
	// 		dispatch(fetchAvailableSlots(1)); // Replace with actual stationId if needed
	// 	}
	// }, [dispatch, selectedDay]);

	const addSlot = (start: string, end: string) => {
		const selectedDateFormatted = selectedDate.format("YYYY-MM-DD");
		const startTime = start;
		const endTime = end;

		dispatch(
			createSlot({
				stationId: 1,
				date: selectedDateFormatted,
				startHour: startTime,
				endHour: endTime,
				isAvailable: true,
			})
		);
	};

	const addBreak = (start: string, end: string) => {
		if (!start || !end) {
			setError("Break Start and End times are required.");
			return;
		}

		setBreakTime([...breakTime, { start, end }]);
		setError("");
	};

	const deleteSlot = (start: string, end: string) => {
		const updatedSlots = slots[selectedDay].filter(
			(slot: any) => !(slot.start === start && slot.end === end)
		);
		setSlots({
			...slots,
			[selectedDay]: updatedSlots,
		});
	};

	const deleteBreak = (start: string, end: string) => {
		const updatedBreaks = breakTime.filter(
			(breakItem: any) =>
				!(breakItem.start === start && breakItem.end === end)
		);
		setBreakTime(updatedBreaks);
	};

	const saveData = () => {
		if (!openingTime || !closingTime) {
			setError("Operating hours are required.");
			return;
		}

		setSuccessMessage(
			`Data for ${selectedDay} has been saved successfully!`
		);
		setError("");
	};

	const handleCloseSnackbar = () => {
		setSuccessMessage(null);
	};

	return (
		<Dialog open={open} onClose={onClose} maxWidth="md" fullWidth>
			<DialogTitle align="center">EV Station Slot Management</DialogTitle>
			<DialogContent>
				{/* Date Picker */}
				<Box
					sx={{
						display: "flex",
						justifyContent: "space-between",
						mt: 3,
					}}
				>
					<Typography variant="h4" gutterBottom>
						Select Date
					</Typography>
					<LocalizationProvider dateAdapter={AdapterDayjs}>
						<DatePicker
							value={selectedDate}
							onChange={(newDate) => setSelectedDate(newDate)}
							renderInput={(props) => (
								<CustomTextField
									{...props}
									fullWidth
									label="Select Date"
									InputProps={{
										startAdornment: (
											<CalendarTodayRoundedIcon fontSize="small" />
										),
									}}
								/>
							)}
						/>
					</LocalizationProvider>
				</Box>

				<Tabs
					value={selectedDay}
					onChange={(event, newValue) => setSelectedDay(newValue)}
					variant="scrollable"
					scrollButtons="auto"
					sx={{ mt: 3 }}
				>
					{days.map((day) => (
						<Tab
							key={day}
							label={day}
							value={day}
							sx={{
								fontWeight: "bold",
								fontSize: "16px",
								"&.Mui-selected": {
									backgroundColor: "#52ACDF",
									color: "white",
									borderRadius: "8px",
								},
							}}
						/>
					))}
				</Tabs>

				{/* Operating Hours */}
				<Card sx={{ mt: 2, p: 2 }}>
					<Typography variant="h6" gutterBottom>
						Set Operating Hours for {selectedDay}
					</Typography>
					<Box sx={{ display: "flex", gap: 2, mt: 1 }}>
						<CustomTextField
							type="time"
							label="Opening Time"
							value={openingTime}
							onChange={(e) => setOpeningTime(e.target.value)}
							fullWidth
						/>
						<CustomTextField
							type="time"
							label="Closing Time"
							value={closingTime}
							onChange={(e) => setClosingTime(e.target.value)}
							fullWidth
						/>
					</Box>
				</Card>

				{/* Slots */}
				<Card sx={{ mt: 2, p: 2 }}>
					<Typography variant="h6">Add Slots</Typography>
					<Box sx={{ display: "flex", gap: 2, mt: 1 }}>
						<CustomTextField
							type="time"
							label="Start Time"
							id="slotStart"
							fullWidth
						/>
						<CustomTextField
							type="time"
							label="End Time"
							id="slotEnd"
							fullWidth
						/>
						<Button
							sx={{
								backgroundColor: "#52ACDF",
								color: "white",
								borderRadius: "8px",
								width: "250px",
								"&:hover": { backgroundColor: "#439BC1" },
							}}
							onClick={() =>
								addSlot(
									document.getElementById("slotStart").value,
									document.getElementById("slotEnd").value
								)
							}
						>
							<AddCircleIcon sx={{ mr: 1 }} /> Add
						</Button>
					</Box>
					{error && (
						<Typography color="error" mt={1}>
							{error}
						</Typography>
					)}
				</Card>

				{/* Break Time */}
				<Card sx={{ mt: 2, p: 2 }}>
					<Typography variant="h6">Break Time</Typography>
					<Box sx={{ display: "flex", gap: 2, mt: 1 }}>
						<CustomTextField
							type="time"
							label="Break Start"
							id="breakStart"
							fullWidth
						/>
						<CustomTextField
							type="time"
							label="Break End"
							id="breakEnd"
							fullWidth
						/>
						<Button
							sx={{
								backgroundColor: "#52ACDF",
								color: "white",
								borderRadius: "8px",
								width: "250px",
								"&:hover": { backgroundColor: "#439BC1" },
							}}
							onClick={() =>
								addBreak(
									document.getElementById("breakStart").value,
									document.getElementById("breakEnd").value
								)
							}
						>
							<AddCircleIcon sx={{ mr: 1 }} /> Add
						</Button>
					</Box>
				</Card>

				{/* Slots and Break Times Lists */}
				{/* (Content for slots and breaks remains the same as in the original implementation) */}

				{/* Success Snackbar */}
				<Snackbar
					open={!!successMessage}
					autoHideDuration={6000}
					onClose={handleCloseSnackbar}
					message={successMessage}
				/>
			</DialogContent>

			<DialogActions>
				<Button onClick={onClose} color="primary">
					Cancel
				</Button>
				<Button onClick={saveData} color="primary">
					Save
				</Button>
			</DialogActions>
		</Dialog>
	);
}


