import React, { useEffect, useState } from "react";
import {
	Tabs,
	Tab,
	Box,
	Card,
	CardContent,
	Button,
	Typography,
	IconButton,
	Stack,
	Snackbar,
} from "@mui/material";
import { CustomTextField } from "../../components/AddEditUserModel/styled.css.tsx";
import AddCircleIcon from "@mui/icons-material/AddCircle";
import DeleteIcon from "@mui/icons-material/Delete";
import CalendarTodayRoundedIcon from "@mui/icons-material/CalendarTodayRounded";
import { LocalizationProvider, DatePicker } from "@mui/x-date-pickers";
import { AdapterDayjs } from "@mui/x-date-pickers/AdapterDayjs";
import dayjs from "dayjs";
import { useNavigate } from "react-router-dom";
import { useDispatch, useSelector } from "react-redux";
import {
	fetchAvailableSlots,
	createSlot,
	deleteSlot,
} from "../../redux/slices/slotSlice.ts";
import { RootState } from "../../redux/reducers.ts";

const days = [
	"Monday",
	"Tuesday",
	"Wednesday",
	"Thursday",
	"Friday",
	"Saturday",
];

export default function EVSlotManagement() {
	const [selectedDay, setSelectedDay] = useState("Monday");
	const [openingTime, setOpeningTime] = useState("");
	const [closingTime, setClosingTime] = useState("");
	const [breakTime, setBreakTime] = useState<any>([]);
	const [error, setError] = useState<string>("");
	const [successMessage, setSuccessMessage] = useState<string | null>(null);
	const [selectedDate, setSelectedDate] = useState<dayjs.Dayjs | null>(
		dayjs()
	);
	const navigate = useNavigate();
	const dispatch = useDispatch();

	const { slots, availableSlots } = useSelector(
		(state: RootState) => state?.slotReducer
	);

	console.log("availableSlots", availableSlots);

	useEffect(() => {
		dispatch(fetchAvailableSlots());
	}, [dispatch]);

	const handleBack = () => {
		navigate("/panel/dashboard");
	};

	const addSlot = (start: string, end: string) => {
		const selectedDateFormatted = selectedDate?.format("YYYY-MM-DD");

		const startTime = start;
		const endTime = end;
		dispatch(
			createSlot({
				date: selectedDateFormatted,
				startHour: startTime,
				endHour: endTime,
				isAvailable: true,
			})
		);
		// dispatch(fetchAvailableSlots());
	};

	// Delete slot function that dispatches deleteSlot
	const addBreak = (start: string, end: string) => {
		if (!start || !end) {
			setError("Break Start and End times are required.");
			return;
		}

		setBreakTime([...breakTime, { start, end }]);
		setError("");
	};

	const handleDeleteSlot = (slotId: number) => {
		dispatch(deleteSlot(slotId));
		dispatch(fetchAvailableSlots());
	};

	// Delete break function
	const deleteBreak = (start: string, end: string) => {
		const updatedBreaks = breakTime.filter(
			(breakItem: any) =>
				!(breakItem.start === start && breakItem.end === end)
		);
		setBreakTime(updatedBreaks);
	};

	// Save function
	const saveData = () => {
		if (!openingTime || !closingTime) {
			setError("Operating hours are required.");
			return;
		}

		// Simulate saving data (e.g., to a database or API)
		setSuccessMessage(
			`Data for ${selectedDay} has been saved successfully!`
		);
		setError(""); // Clear any previous errors
	};

	const handleCloseSnackbar = () => {
		setSuccessMessage(null);
	};

	return (
		<Box sx={{ maxWidth: 600, mx: "auto", p: 2 }}>
			<Typography variant="h4" gutterBottom align="center">
				EV Station Slot Management
			</Typography>

			{/* Date Picker */}
			<Box
				sx={{ display: "flex", justifyContent: "space-between", mt: 3 }}
			>
				<Typography variant="h4" gutterBottom align="center">
					Select Date
				</Typography>
				<LocalizationProvider dateAdapter={AdapterDayjs}>
					<DatePicker
						value={selectedDate}
						onChange={(newDate) => setSelectedDate(newDate)}
						renderInput={(props) => (
							<CustomTextField
								{...props}
								fullWidth
								label="Select Date"
								InputProps={{
									startAdornment: (
										<CalendarTodayRoundedIcon fontSize="small" />
									),
								}}
							/>
						)}
					/>
				</LocalizationProvider>
			</Box>

			<Tabs
				value={selectedDay}
				onChange={(event, newValue) => setSelectedDay(newValue)}
				variant="scrollable"
				scrollButtons="auto"
				sx={{ mt: 3 }}
			>
				{days.map((day) => (
					<Tab
						key={day}
						label={day}
						value={day}
						sx={{
							fontWeight: "bold",
							fontSize: "16px",
							"&.Mui-selected": {
								backgroundColor: "#52ACDF",
								color: "white",
								borderRadius: "8px",
							},
						}}
					/>
				))}
			</Tabs>

			<Card sx={{ mt: 2, p: 2 }}>
				<Typography variant="h6">Add Slots</Typography>
				<Box sx={{ display: "flex", gap: 2, mt: 1 }}>
					<CustomTextField
						type="time"
						label="Start Time"
						id="slotStart"
						fullWidth
					/>
					<CustomTextField
						type="time"
						label="End Time"
						id="slotEnd"
						fullWidth
					/>
					<Button
						sx={{
							backgroundColor: "#52ACDF",
							color: "white",
							borderRadius: "8px",
							width: "250px",
							"&:hover": { backgroundColor: "#439BC1" },
						}}
						onClick={() =>
							addSlot(
								document.getElementById("slotStart").value,
								document.getElementById("slotEnd").value
							)
						}
					>
						<AddCircleIcon sx={{ mr: 1 }} /> Add
					</Button>
				</Box>
				{error && (
					<Typography color="error" mt={1}>
						{error}
					</Typography>
				)}
			</Card>
			<Card sx={{ mt: 2, p: 2 }}>
				<Typography variant="h6">Break Time</Typography>
				<Box sx={{ display: "flex", gap: 2, mt: 1 }}>
					<CustomTextField
						type="time"
						label="Break Start"
						id="breakStart"
						fullWidth
					/>
					<CustomTextField
						type="time"
						label="Break End"
						id="breakEnd"
						fullWidth
					/>
					<Button
						sx={{
							backgroundColor: "#52ACDF",
							color: "white",
							borderRadius: "8px",
							width: "250px",
							"&:hover": { backgroundColor: "#439BC1" },
						}}
						onClick={() =>
							addBreak(
								document.getElementById("breakStart").value,
								document.getElementById("breakEnd").value
							)
						}
					>
						<AddCircleIcon sx={{ mr: 1 }} /> Add
					</Button>
				</Box>
			</Card>
			<Card sx={{ mt: 2, p: 2 }}>
				<Typography variant="h6" gutterBottom>
					Slots for {selectedDay}
				</Typography>
				{Array.isArray(availableSlots) && availableSlots.length ? (
					availableSlots.map((slot: any, index: number) => (
						<Box
							key={index}
							sx={{
								display: "flex",
								justifyContent: "space-between",
								alignItems: "center",
								mb: 1,
							}}
						>
							<Typography variant="body1">
								{dayjs(slot.date).format("YYYY-MM-DD")} -{" "}
								{dayjs(slot.startTime).format("HH:mm")} -{" "}
								{dayjs(slot.endTime).format("HH:mm")}
							</Typography>
							<IconButton
								onClick={() => handleDeleteSlot(slot.id)}
							>
								<DeleteIcon color="error" />
							</IconButton>
						</Box>
					))
				) : (
					<Typography>No slots added for {selectedDay}</Typography>
				)}
			</Card>

			<Card sx={{ mt: 2, p: 2 }}>
				<Typography variant="h6" gutterBottom>
					Break Times for {selectedDay}
				</Typography>
				{breakTime.length ? (
					breakTime.map((breakItem: any, index: number) => (
						<Box
							key={index}
							sx={{
								display: "flex",
								justifyContent: "space-between",
								alignItems: "center",
								mb: 1,
							}}
						>
							<Typography variant="body1">
								{breakItem.start} - {breakItem.end}
							</Typography>
							<IconButton
								onClick={() =>
									deleteBreak(breakItem.start, breakItem.end)
								}
							>
								<DeleteIcon color="error" />
							</IconButton>
						</Box>
					))
				) : (
					<Typography>No break times added</Typography>
				)}
			</Card>
			{/* <Box
				sx={{ display: "flex", justifyContent: "space-between", mt: 3 }}
			>
				<Button
					sx={{
						backgroundColor: "#52ACDF",
						color: "white",
						borderRadius: "8px",
						"&:hover": { backgroundColor: "#439BC1" },
						width: "117px",
					}}
					onClick={handleBack}
				>
					Back
				</Button>
				<Button
					type="submit"
					sx={{
						backgroundColor: "#52ACDF",
						color: "white",
						borderRadius: "8px",
						width: "117px",
						"&:hover": { backgroundColor: "#439BC1" },
					}}
					onClick={saveData}
				>
					Save
				</Button>
			</Box> */}

			{/* Success Snackbar */}
			{/* <Snackbar
				open={!!successMessage}
				autoHideDuration={6000}
				onClose={handleCloseSnackbar}
				message={successMessage}
			/> */}
		</Box>
	);
}
