import { createSlice, createAsyncThunk, PayloadAction } from "@reduxjs/toolkit";
import http from "../../lib/https";
import { toast } from "sonner";

interface Booking {
	id: number;
    name:string;
	stationId: string;
	date: string;
	startTime: string;
	endTime: string;
}
interface BookingState {
	bookings: Booking[];
	loading: boolean;
	error: string | null;
}
const initialState: BookingState = {
	bookings: [],
	loading: false,
	error: null,
};

export const bookingList = createAsyncThunk<
	Booking,
	void,
	{ rejectValue: string }
>("fetchBooking", async (_, { rejectWithValue }) => {
	try {
		const token = localStorage?.getItem("authToken");
		if (!token) throw new Error("No token found");

		const response = await http.get("/user-bookings");

		if (!response.data?.data) throw new Error("Invalid API response");

		return response.data.data;
	} catch (error: any) {
		toast.error("Error Fetching User Booking List" + error);
		return rejectWithValue(
			error?.response?.data?.message || "An error occurred"
		);
	}
});

export const addBooking = createAsyncThunk<
	Booking,
	{
		stationId: string;
		date: string;
		startTime: string;
		endTime: string;
	},
	{ rejectValue: string }
>("/AddBooking", async (data, { rejectWithValue }) => {
	try {
		const response = await http.post("/book-slot", data);
		return response.data;
	} catch (error: any) {
		return rejectWithValue(
			error.response?.data?.message || "An error occurred"
		);
	}
});

const bookSlice = createSlice({
	name: "booking",
	initialState,
	reducers: {},
	extraReducers: (builder) => {
		builder
			.addCase(bookingList.pending, (state) => {
				state.loading = true;
				state.error = null;
			})
			.addCase(
				bookingList.fulfilled,
				(state, action: PayloadAction<Booking[]>) => {
					state.loading = false;
					state.bookings = action.payload;
				}
			)
			.addCase(bookingList.rejected, (state, action) => {
				state.loading = false;
				state.error = action.error.message || "Failed to fetch users";
			})
			.addCase(addBooking.pending, (state) => {
				state.loading = true;
				// state.error = null;
			})
			.addCase(
				addBooking.fulfilled,
				(state, action: PayloadAction<Booking>) => {
					state.loading = false;
					state.bookings.push(action.payload);
				}
			)
			.addCase(
				addBooking.rejected,
				(state, action: PayloadAction<string | undefined>) => {
					state.loading = false;
				}
			);
	},
});

export default bookSlice.reducer;
